<p align="center">
  <img src="https://github.com/Zeqiang-Lai/dola-kit/assets/26198430/c5df07ef-5d0c-4b9b-ac3d-26a00a1229d0" alt="" width="25%">
<p align="center">
  <b>A toolkit for personal use.</b>
</p>
</p>

## Install
<a href="[https://pypi.org/project/dprox/](https://pypi.org/project/dola/)">
<img alt="PyPI - Downloads" src="https://img.shields.io/pypi/v/dola">
</a>
    
```bash
pip install dola
pip install git+https://github.com/Zeqiang-Lai/dola-kit.git
```

## Usage

```python
import dola

dola.filename('path/input.png')
# input.png
```

## Acknowledgement

[kiuikit](https://github.com/ashawkey/kiuikit)
